@@ -1,6 +1,6 @@
 from .linear_decoder import AutoencoderLinearDecoder, train_autoencoder
 from .model import Intercode
-from .utils import add_annotations
+from .utils import add_annotations, score_logistic
 
 __author__ = 'Sergei Rybakov'
 __email__ = 'sergei.rybakov@helmholtz-muenchen.de'
